@@ -15,18 +15,6 @@ test_expect_success 'Testing tomb creation: dig, forge and lock' '
     tt_lock --tomb-pwd $DUMMYPASS
     '
 
-if test_have_prereq SPHINX ORACLE; then
-	test_export "sphinx_test"
-	test_expect_success 'Testing tomb creation: dig, forge and lock (sphinx password handling)' '
-        tt_dig -s 20 &&
-        tt_forge --tomb-pwd $DUMMYPASS --sphx-user $DUMMYUSER --sphx-host $DUMMYHOST &&
-        print $(echo $DUMMYPASS | sphinx get $DUMMYUSER $DUMMYHOST) \
-            | gpg --batch --passphrase-fd 0 --no-tty --no-options -d $tomb_key \
-            | xxd &&
-        tt_lock --tomb-pwd $DUMMYPASS --sphx-user $DUMMYUSER --sphx-host $DUMMYHOST
-        '
-fi
-
 if test_have_prereq DOAS; then
     test_export "doas_test"
     test_expect_success 'Testing tomb creation: dig, forge and lock (using doas instead of sudo)' '
@@ -39,4 +27,26 @@ if test_have_prereq DOAS; then
         '
 fi
 
+if test_have_prereq BTRFS; then
+    test_export "btrfs"
+    test_expect_success 'Testing tomb creation using BTRFS filesystem' '
+    tt_dig -s 120 &&
+    tt_forge --tomb-pwd $DUMMYPASS &&
+    print $DUMMYPASS \
+        | gpg --batch --passphrase-fd 0 --no-tty --no-options -d $tomb_key \
+        | xxd &&
+    tt_lock --tomb-pwd $DUMMYPASS --filesystem btrfs
+    '
+
+    test_export "btrfsmixed"
+    test_expect_success 'Testing tomb creation using BTRFS mixedmode filesystem' '
+    tt_dig -s 20 &&
+    tt_forge --tomb-pwd $DUMMYPASS &&
+    print $DUMMYPASS \
+        | gpg --batch --passphrase-fd 0 --no-tty --no-options -d $tomb_key \
+        | xxd &&
+    tt_lock --tomb-pwd $DUMMYPASS --filesystem btrfsmixedmode
+    '
+fi
+
 test_done
